
      SUBROUTINE UGEOM
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                              C
C     UGEOM is a user subroutine which defines the geometrical set-up.         C
C                                                                              C
C                                                                              C
C		W. Lorenzon    March  21/94                                          C
C		J. Seibert     1998                                                  C
C		W. Lorenzon,   January 18/99										 C   
C         Andy Raj       May 16th 99 -- new config 4x4 c.s. tungsten.          C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
C
      IMPLICIT NONE
C
      include 'user.cmn'
C
C Geometry parameters
      real par(8), w_pos, sc_pos
	real inch
	parameter (inch=2.54)
C
C  Geometry variables
      integer   ivolu, nmed
C  index variables
	integer ii
C
C Volume definition and configuration.   
C
C The mother volume is a box. Coordinate system
C	Z: beam direction is +Z
C	Y: +Y is up
C	X:  X = Y x Z
C  Origin: center of tube cross
C
C  Rotation Matrices
      call gsrotm(1,90.,0.,180.,0.,90.,90.)  ! z along Lab Y, y along -Z, x along X
      call gsrotm(2,135.,0.,90.,90.,45.,0.)  ! z 45' between X,Z, y on Y, x betwn X,-Z
      call gsrotm(3,135.,180.,90.,90.,135.,0.) ! z 45' between X,-Z, y on Y, x betwn -X,-Z
C
C               Define User's Volume
C
      nmed = 1			! big box

      par(1) = 10.              ! half length along x axis
      par(2) = 10.              ! half length along y axis
      par(3) = 30.              ! half length along z axis
      CALL GSVOLU('COVE','BOX ',nmed,par,3,ivolu)  ! the Mother of all volumes !


      nmed = 4				! Tungsten "slice"
		      
      par(1) = 4.0 / 2.
      par(2) = 4.0 / 2.
cabr      par(3) = 0.635 / 2.
      par(3) = 0.3 / 2.
      CALL GSVOLU('WSLI','BOX ',nmed,par,3,ivolu)  

      par(1) = 0.2/2.           ! Left Plate (close to beam)
      par(2) = 8./2.
      par(3) = 20./2.
      CALL GSVOLU('LPLT','BOX ',nmed,par,3,ivolu)

      par(1) = 0.2/2.           ! Right Plate (away from beam)
      par(2) = 8./2.
      par(3) = 20./2.
      CALL GSVOLU('RPLT','BOX ',nmed,par,3,ivolu)


      nmed = 12				! Scintillator plates
cabr changing dimension of scintillator block to 4.0 X 4.0
cabr      par(1) = 5.08/2.
cabr      par(2) = 5.08/2.
      par(1) = 4.0/2.
      par(2) = 4.0/2.
      par(3) = .26/2.
      CALL GSVOLU('SCPL','BOX ',nmed,par,3,ivolu)


      nmed = 6                  ! Al mounts, etc.

      par(1) = 9.5/2.           ! Front Plate
      par(2) = 8./2.
      par(3) = 1.0/2.
      CALL GSVOLU('FPLT','BOX ',nmed,par,3,ivolu)

      par(1) = 9.5/2.           ! Bottom Plate
      par(2) = 1.0/2.
      par(3) = 20./2.
      CALL GSVOLU('BPLT','BOX ',nmed,par,3,ivolu)

      par(1) = 9.5/2.           ! Top Plate
      par(2) = 1.0/2.
      par(3) = 20./2.
      CALL GSVOLU('TPLT','BOX ',nmed,par,3,ivolu)

C
C               Position volumes within COVE
C
C
C  Tungsten / Scintillator detector
C

c  WSLI thickness is 6.35 mm
c  SCPL thickness is 2.6  mm
c  spacing is        0.1  mm
c
c  the scintillator or tungsten plate is always put in center of
c  space it has to fill up:
c	i.e. 0.635 cm /2 = 0.3175 cm  for 1st W plate
c          0.635 cm + (0.26 + 0.01 cm / 2) = 0.7700 for 1st SCPL plate
c          etc 
c
cwl  DON't forget to change the W thickness above to 0.635 mm
cwl
cwl	do ii=1,12
cwl		w_pos  = (0.635+0.27)*(ii-1) + 0.635/2.
cwl		sc_pos = (0.635+0.27)*(ii-1) + (0.635+0.27/2.)
cwl		CALL GSPOS('WSLI', ii, 'COVE', 0., 0., w_pos,  0, 'ONLY')
cwl		CALL GSPOS('SCPL', ii, 'COVE', 0., 0., sc_pos, 0, 'ONLY')
cwl	enddo
cwl
cwl
cwl   add one extra layer of W in front of 24 W plates: for synchrotron
cwl   radiation protection
cwl  DON't forget to change the W thickness above to 0.3 mm
cwl
	do ii=1,24
		w_pos  = (0.3+0.27)*(ii-1) + 0.3/2.
		sc_pos = (0.3+0.27)*(ii-1) + (0.3+0.27/2.)
		CALL GSPOS('WSLI', ii, 'COVE', 0., 0., w_pos,  0, 'ONLY')
		CALL GSPOS('SCPL', ii, 'COVE', 0., 0., sc_pos, 0, 'ONLY')
	enddo
	CALL GSPOS('WSLI', 25, 'COVE', 0., 0., -0.15,  0, 'ONLY')

cwl      CALL GSPOS('WSLI', 1, 'COVE', 0., 0., 0.3175, 0, 'ONLY')
cwl      CALL GSPOS('SCPL', 1, 'COVE', 0., 0., 0.7700, 0, 'ONLY')
cwl      CALL GSPOS('WSLI', 2, 'COVE', 0., 0., 1.2225, 0, 'ONLY')
cwl      CALL GSPOS('SCPL', 2, 'COVE', 0., 0., 1.6750, 0, 'ONLY')
cwl      CALL GSPOS('WSLI', 3, 'COVE', 0., 0., 2.1275, 0, 'ONLY')
cwl      CALL GSPOS('SCPL', 3, 'COVE', 0., 0., 2.5800, 0, 'ONLY')
cwl      CALL GSPOS('WSLI', 4, 'COVE', 0., 0., 3.0325, 0, 'ONLY')
cwl      CALL GSPOS('SCPL', 4, 'COVE', 0., 0., 3.4850, 0, 'ONLY')
cwl      CALL GSPOS('WSLI', 5, 'COVE', 0., 0., 3.9375, 0, 'ONLY')
cwl      CALL GSPOS('SCPL', 5, 'COVE', 0., 0., 4.3900, 0, 'ONLY')
cwl      CALL GSPOS('WSLI', 6, 'COVE', 0., 0., 4.8425, 0, 'ONLY')
cwl      CALL GSPOS('SCPL', 6, 'COVE', 0., 0., 5.2950, 0, 'ONLY')
cwl      CALL GSPOS('WSLI', 7, 'COVE', 0., 0., 5.7475, 0, 'ONLY')
cwl      CALL GSPOS('SCPL', 7, 'COVE', 0., 0., 6.2000, 0, 'ONLY')
cwl      CALL GSPOS('WSLI', 8, 'COVE', 0., 0., 6.6525, 0, 'ONLY')
cwl      CALL GSPOS('SCPL', 8, 'COVE', 0., 0., 7.1050, 0, 'ONLY')
cwl      CALL GSPOS('WSLI', 9, 'COVE', 0., 0., 7.5575, 0, 'ONLY')
cwl      CALL GSPOS('SCPL', 9, 'COVE', 0., 0., 8.0100, 0, 'ONLY')
cwl      CALL GSPOS('WSLI',10, 'COVE', 0., 0., 8.4625, 0, 'ONLY')
cwl      CALL GSPOS('SCPL',10, 'COVE', 0., 0., 8.9150, 0, 'ONLY')
cwl      CALL GSPOS('WSLI',11, 'COVE', 0., 0., 9.3675, 0, 'ONLY')
cwl      CALL GSPOS('SCPL',11, 'COVE', 0., 0., 9.8200, 0, 'ONLY')
cwl      CALL GSPOS('WSLI',12, 'COVE', 0., 0.,10.2725, 0, 'ONLY')
cwl      CALL GSPOS('SCPL',12, 'COVE', 0., 0.,10.7250, 0, 'ONLY')

c
c  cover + side plates
c

      CALL GSPOS('LPLT', 1, 'COVE', -4.2/2., 1./2., 20.0/2.,0, 'ONLY')
      CALL GSPOS('RPLT', 1, 'COVE', 4.2/2., 1./2., 20.0/2.,0, 'ONLY')
      CALL GSPOS('FPLT', 1, 'COVE', 3.2/2.,1.2/2.,-1.0/2.,0,'ONLY')
      CALL GSPOS('BPLT', 1, 'COVE', 4/2.,-5.0/2.,20.0/2.,0,'ONLY')
      CALL GSPOS('TPLT', 1, 'COVE', 4/2.,5.0/2.,20.0/2.,0,'ONLY')
C
C  Optimization calls

      CALL GGCLOS
C
C Print volume parameters and exit
C
      CALL GPVOLU(0)
C
      RETURN
      END
